@@ -261,7 +261,6 @@ class RPMClusters:
         """
         Re-cluster data by minimizing the sum of the:
         - distance between each point and each cluster centroid
-        - distance between each point and each
 
         Parameters
         ----------
@@ -322,7 +321,7 @@ class RPMClusters:
         """
         geometry = [Point(xy) for xy in zip(meta.longitude, meta.latitude)]
         gdf_points = gpd.GeoDataFrame(meta, geometry=geometry,
-                                      crs={'init': 'epsg:4326'})
+                                      crs="EPSG:5070")
 
         clusters, mean_dist = cls._get_cluster_geom(gdf_points)
 
@@ -345,7 +344,8 @@ class RPMClusters:
         meta = self._meta
 
         geometry = [Point(xy) for xy in zip(meta.longitude, meta.latitude)]
-        gdf_points = gpd.GeoDataFrame(meta, geometry=geometry)
+        gdf_points = gpd.GeoDataFrame(meta, geometry=geometry,
+                                      crs="EPSG:5070")
 
         clusters, mean_dist = self._get_cluster_geom(gdf_points)
 
@@ -474,11 +474,12 @@ class RPMClusters:
         method_kwargs : dict
             Kwargs for running _cluster_coefficients
         dist_rank_filter : bool
-            Run _optimize_dist_rank
+            Re-cluster data by minimizing the sum of the:
+            - distance between each point and each cluster centroid
         dist_rmse_kwargs : dict
             Kwargs for running _dist_rank_optimization
         contiguous_filter : bool
-            Run _contiguous_filter
+            Re-classify clusters by making contigous cluster polygons
         contiguous_kwargs : dict
             Kwargs for _contiguous_filter
 
