@@ -12,6 +12,7 @@ from pandas.testing import assert_frame_equal
 import rasterio
 
 from reV.handlers.exclusions import ExclusionLayers
+from reV.handlers.outputs import Outputs
 
 from reVX.handlers.geotiff import Geotiff
 from reVX.utilities.exceptions import ExclusionsCheckError
@@ -151,7 +152,7 @@ class ExclusionsConverter:
 
     @staticmethod
     def _check_geotiff(excl_h5, geotiff, chunks=(128, 128),
-                       transform_atol=0.01, coord_atol=0.00001):
+                       transform_atol=0.01, coord_atol=0.001):
         """
         Compare geotiff with exclusion layer, raise any errors
 
@@ -223,7 +224,7 @@ class ExclusionsConverter:
 
     @classmethod
     def _parse_tiff(cls, geotiff, excl_h5=None, chunks=(128, 128),
-                    transform_atol=0.01, coord_atol=0.00001):
+                    check_tiff=True, transform_atol=0.01, coord_atol=0.001):
         """
         Extract exclusion layer from given geotiff, compare with excl_h5
         if provided
@@ -232,15 +233,19 @@ class ExclusionsConverter:
         ----------
         geotiff : str
             Path to geotiff file
-        excl_h5 : str
-            Path to .h5 file containing exclusion layers
-        chunks : tuple
-            Chunk size of exclusions in Geotiff
-        transform_atol : float
-            Absolute tolerance parameter when comparing geotiff transform data.
-        coord_atol : float
+        excl_h5 : str, optional
+            Path to .h5 file containing exclusion layers, by default None
+        chunks : tuple, optional
+            Chunk size of exclusions in Geotiff, by default (128, 128)
+        check_tiff : bool, optional
+            Flag to check tiff profile and coordinates against exclusion .h5
+            profile and coordinates, by default True
+        transform_atol : float, optional
+            Absolute tolerance parameter when comparing geotiff transform data,
+            by default 0.01
+        coord_atol : float, optional
             Absolute tolerance parameter when comparing new un-projected
-            geotiff coordinates against previous coordinates.
+            geotiff coordinates against previous coordinates, by default 0.001
 
         Returns
         -------
@@ -249,7 +254,7 @@ class ExclusionsConverter:
         values : ndarray
             Geotiff data
         """
-        if excl_h5 is not None:
+        if excl_h5 is not None and check_tiff:
             cls._check_geotiff(excl_h5, geotiff, chunks=chunks,
                                transform_atol=transform_atol,
                                coord_atol=coord_atol)
@@ -261,7 +266,7 @@ class ExclusionsConverter:
 
     @staticmethod
     def _write_layer(excl_h5, layer, profile, values, chunks=(128, 128),
-                     description=None):
+                     description=None, scale_factor=None):
         """
         Extract given layer from geotiff .tif and write to .h5 file
 
@@ -279,9 +284,12 @@ class ExclusionsConverter:
             Chunk size of dataset in .h5 file
         description : str
             Description of exclusion layer
+        scale_factor : int | float, optional
+            Scale factor to use to scale geotiff data when added to the .h5
+            file, by default None
         """
         if len(chunks) < 3:
-            chunks = (1,) + chunks
+            chunks = (1, ) + chunks
 
         with h5py.File(excl_h5, mode='a') as f:
             ds = f.create_dataset(layer, shape=values.shape,
@@ -296,10 +304,15 @@ class ExclusionsConverter:
                 logger.debug('\t- Description for {} added:\n{}'
                              .format(layer, description))
 
+            if scale_factor is not None:
+                ds.attrs['scale_factor'] = scale_factor
+                logger.debug('\t- scale_factor for {} added:\n{}'
+                             .format(layer, scale_factor))
+
     @classmethod
     def _geotiff_to_h5(cls, excl_h5, layer, geotiff, chunks=(128, 128),
-                       transform_atol=0.01, coord_atol=0.00001,
-                       description=None):
+                       check_tiff=True, transform_atol=0.01, coord_atol=0.001,
+                       description=None, scale_factor=None, dtype='int16'):
         """
         Transfer geotiff exclusions to h5 confirming they match existing layers
 
@@ -311,25 +324,40 @@ class ExclusionsConverter:
             Layer to extract
         geotiff : str
             Path to geotiff file
-        chunks : tuple
-            Chunk size of exclusions in .h5 and Geotiffs
-        transform_atol : float
-            Absolute tolerance parameter when comparing geotiff transform data.
-        coord_atol : float
+        chunks : tuple, optional
+            Chunk size of exclusions in Geotiff, by default (128, 128)
+        check_tiff : bool, optional
+            Flag to check tiff profile and coordinates against exclusion .h5
+            profile and coordinates, by default True
+        transform_atol : float, optional
+            Absolute tolerance parameter when comparing geotiff transform data,
+            by default 0.01
+        coord_atol : float, optional
             Absolute tolerance parameter when comparing new un-projected
-            geotiff coordinates against previous coordinates.
-        description : str
-            Description of exclusion layer
+            geotiff coordinates against previous coordinates, by default 0.001
+        description : str, optional
+            Description of exclusion layer, by default None
+        scale_factor : int | float, optional
+            Scale factor to use to scale geotiff data when added to the .h5
+            file, by default None
+        dtype : str, optional
+            Dtype to save geotiff data as in the .h5 file. Only used when
+            'scale_factor' is not None, by default 'int16'
         """
         logger.debug('\t- {} being extracted from {} and added to {}'
                      .format(layer, geotiff, os.path.basename(excl_h5)))
 
         profile, values = cls._parse_tiff(
-            geotiff, excl_h5=excl_h5, chunks=chunks,
+            geotiff, excl_h5=excl_h5, chunks=chunks, check_tiff=check_tiff,
             transform_atol=transform_atol, coord_atol=coord_atol)
 
+        if scale_factor is not None:
+            values = Outputs._check_data_dtype(values, dtype,
+                                               scale_factor=scale_factor)
+
         cls._write_layer(excl_h5, layer, profile, values,
-                         chunks=chunks, description=description)
+                         chunks=chunks, description=description,
+                         scale_factor=scale_factor)
 
     @staticmethod
     def _write_geotiff(geotiff, profile, values):
@@ -385,8 +413,9 @@ class ExclusionsConverter:
 
         return profile, values
 
-    def geotiff_to_layer(self, layer, geotiff, transform_atol=0.01,
-                         coord_atol=0.00001, description=None):
+    def geotiff_to_layer(self, layer, geotiff, check_tiff=True,
+                         transform_atol=0.01, coord_atol=0.001,
+                         description=None, scale_factor=None, dtype='int16'):
         """
         Transfer geotiff exclusions to h5 confirming they match existing layers
 
@@ -396,13 +425,23 @@ class ExclusionsConverter:
             Layer to extract
         geotiff : str
             Path to geotiff file
-        transform_atol : float
-            Absolute tolerance parameter when comparing geotiff transform data.
-        coord_atol : float
+        check_tiff : bool, optional
+            Flag to check tiff profile and coordinates against exclusion .h5
+            profile and coordinates, by default True
+        transform_atol : float, optional
+            Absolute tolerance parameter when comparing geotiff transform data,
+            by default 0.01
+        coord_atol : float, optional
             Absolute tolerance parameter when comparing new un-projected
-            geotiff coordinates against previous coordinates.
-        description : str
-            Description of exclusion layer
+            geotiff coordinates against previous coordinates, by default 0.001
+        description : str, optional
+            Description of exclusion layer, by default None
+        scale_factor : int | float, optional
+            Scale factor to use to scale geotiff data when added to the .h5
+            file, by default None
+        dtype : str, optional
+            Dtype to save geotiff data as in the .h5 file. Only used when
+            'scale_factor' is not None, by default 'int16'
         """
         if not os.path.exists(self._excl_h5):
             self._init_h5(self._excl_h5, geotiff, chunks=self._chunks)
@@ -414,9 +453,12 @@ class ExclusionsConverter:
 
         self._geotiff_to_h5(self._excl_h5, layer, geotiff,
                             chunks=self._chunks,
+                            check_tiff=check_tiff,
                             transform_atol=transform_atol,
                             coord_atol=coord_atol,
-                            description=description)
+                            description=description,
+                            scale_factor=scale_factor,
+                            dtype=dtype)
 
     def layer_to_geotiff(self, layer, geotiff):
         """
@@ -433,9 +475,9 @@ class ExclusionsConverter:
                             hsds=self._hsds)
 
     @classmethod
-    def layers_to_h5(cls, excl_h5, layers, chunks=(128, 128),
-                     transform_atol=0.01, coord_atol=0.00001,
-                     descriptions=None):
+    def layers_to_h5(cls, excl_h5, layers, chunks=(128, 128), check_tiff=True,
+                     transform_atol=0.01, coord_atol=0.001,
+                     descriptions=None, scale_factors=None):
         """
         Create exclusions .h5 file from provided geotiffs
 
@@ -446,32 +488,52 @@ class ExclusionsConverter:
         layers : list | dict
             List of geotiffs to load
             or dictionary mapping goetiffs to the layers to load
-        chunks : tuple
-            Chunk size of exclusions in .h5 and Geotiffs
-        transform_atol : float
-            Absolute tolerance parameter when comparing geotiff transform data.
-        coord_atol : float
+        chunks : tuple, optional
+            Chunk size of exclusions in Geotiff, by default (128, 128)
+        check_tiff : bool, optional
+            Flag to check tiff profile and coordinates against exclusion .h5
+            profile and coordinates, by default True
+        transform_atol : float, optional
+            Absolute tolerance parameter when comparing geotiff transform data,
+            by default 0.01
+        coord_atol : float, optional
             Absolute tolerance parameter when comparing new un-projected
-            geotiff coordinates against previous coordinates.
-        descriptions : dict | NoneType
-            Descriptions for layers to be writen to .h5
+            geotiff coordinates against previous coordinates, by default 0.001
+        description : str, optional
+            Description of exclusion layer, by default None
+        scale_factor : dict, optional
+            Scale factors and dtypes to use when scaling given layers,
+            by default None
         """
         if isinstance(layers, list):
-            layers = {os.path.basename(l).split('.')[0]: l
-                      for l in layers}
+            layers = {os.path.basename(lyr).split('.')[0]: lyr
+                      for lyr in layers}
 
         if descriptions is None:
             descriptions = {}
 
+        if scale_factors is None:
+            scale_factors = {}
+
         excls = cls(excl_h5, chunks=chunks)
         logger.info('Creating {}'.format(excl_h5))
         for layer, geotiff in layers.items():
             logger.info('- Transfering {}'.format(layer))
             description = descriptions.get(layer, None)
-            excls.geotiff_to_layer(layer, geotiff,
+            scale = scale_factors.get(layer, None)
+            if scale is not None:
+                scale_factor = scale['scale_factor']
+                dtype = scale['dtype']
+            else:
+                scale_factor = None
+                dtype = None
+
+            excls.geotiff_to_layer(layer, geotiff, check_tiff=check_tiff,
                                    transform_atol=transform_atol,
                                    coord_atol=coord_atol,
-                                   description=description)
+                                   description=description,
+                                   scale_factor=scale_factor,
+                                   dtype=dtype)
 
     @classmethod
     def extract_layers(cls, excl_h5, layers, chunks=(128, 128),
